@@ -1,3 +1,6 @@
+# Copyright (c) Sualeh Fatehi
+# SPDX-License-Identifier: EPL-2.0
+
 from __future__ import print_function
 import re
 
@@ -32,6 +35,6 @@ for table in catalog.tables:
     print('')
 
 for table in catalog.tables:
-    for childTable in table.referencingTables:
+    for childTable in table.dependentTables:
         print('  ' + cleanname(table.fullName) + ' ||--o{ ' +
               cleanname(childTable.fullName) + ' : "foreign key"')
